@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2018-2021, earthobservations developers.
+# Copyright (C) 2018-2021, earthobservations developers.
 # Distributed under the MIT License. See LICENSE for more info.
 from enum import Enum
 
@@ -20,6 +20,7 @@ class Resolution(Enum):
     MINUTE_1 = "1_minute"  # used by DWD for file server
     MINUTE_5 = "5_minutes"
     MINUTE_10 = "10_minutes"  # used by DWD for file server
+    MINUTE_15 = "15_minutes"  # used by DWD for file server
     HOURLY = "hourly"  # used by DWD for file server
     HOUR_6 = "6_hour"
     SUBDAILY = "subdaily"  # used by DWD for file server
@@ -34,8 +35,11 @@ class Resolution(Enum):
 
 class Frequency(Enum):
     MINUTE_1 = "1min"
+    MINUTE_2 = "2min"
     MINUTE_5 = "5min"
     MINUTE_10 = "10min"
+    MINUTE_15 = "15min"
+    MINUTE_60 = "60min"  # similar to hourly, needed for WSV frequency detection
     HOURLY = "1H"
     HOUR_6 = "6H"
     SUBDAILY = "1H"
