@@ -1,11 +1,11 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2018-2021, earthobservations developers.
+# Copyright (C) 2018-2021, earthobservations developers.
 # Distributed under the MIT License. See LICENSE for more info.
 from enum import Enum
 
 
 class DwdOrigColumns(Enum):
-    """ Original meta column names from DWD data """
+    """Original meta column names from DWD data"""
 
     STATION_ID = "stations_id"
     DATE = "mess_datum"
@@ -23,7 +23,7 @@ class DwdOrigColumns(Enum):
 
 
 class DwdColumns(Enum):
-    """ Overhauled column names for metadata fields """
+    """Overhauled column names for metadata fields"""
 
     STATION_ID = "station_id"  # change to local id later
     DATE = "date"
@@ -43,7 +43,7 @@ class DwdColumns(Enum):
     INTERVAL = "interval"
     # Columns used for tidy data
     # Column for quality
-    PARAMETER_SET = "parameter_set"
+    DATASET = "dataset"
     PARAMETER = "parameter"
     VALUE = "value"
     QUALITY = "quality"
