@@ -1,6 +1,10 @@
 # -*- coding: utf-8 -*-
 # Copyright (C) 2018-2021, earthobservations developers.
 # Distributed under the MIT License. See LICENSE for more info.
-from wetterdienst.provider.dwd.mosmix.api import DwdMosmixRequest, DwdMosmixValues
+from wetterdienst.provider.dwd.mosmix.api import (
+    DwdMosmixRequest,
+    DwdMosmixStationGroup,
+    DwdMosmixValues,
+)
 from wetterdienst.provider.dwd.mosmix.metadata.dates import DwdForecastDate
 from wetterdienst.provider.dwd.mosmix.metadata.mosmix_type import DwdMosmixType
